// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Data types that can be used in data tables
///
/// These data types are similar to the data types that can be stored in SQLite.
enum DataType {
  /// Mathematical integer
  integer,

  /// Real number
  real,

  /// Text string
  text
}

/// General table rejection reasons
///
/// If the reason for rejection is not in this enumeration, the enumeration
/// should be extended.
enum TableRejectionReason {
  /// All table fields must be distinctive.
  duplicateFields,

  /// A data class is incompatible if it is already used elsewhere with a
  /// different data type, or in a different group (keys can only be used as
  /// keys and vice versa). Keys that are once defined as canonical should
  /// always be defined as canonical.
  incompatibleDataClass,

  /// All table names should be unique within the provider.
  duplicateTableName,

  /// New tables should not break the relational mapping.
  breaksRelationalMapping
}

/// Superclass for fields and keys
abstract class TableField {
  /// Data type
  final DataType dataType;

  /// Data class
  ///
  /// The data class decribes what kind of data is stored in this field.
  /// Standard class strings are defined in this library and should be used when
  /// possible. The class string is used to identify the same data fields across
  /// separate tables.
  final String dataClass;

  /// Constructor
  const TableField(this.dataType, this.dataClass);
}
