// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Key relational type
enum KeyRelationType {
  /// This key is unique
  /// (each unique record has a unique key value)
  oneToOne,

  /// This key can be linked to many records
  /// (many records exist with the same key value)
  manyToOne,

  /// This record can be linked with many keys
  /// (one record has many keys that are unique in the table)
  oneToMany,

  /// This record can be linked with many keys that can be linked to many
  /// records.
  /// (one record has many keys that can also be linked to other records)
  manyToMany
}

/// Table key
class TableKey extends TableField {
  /// Relation that is described by this key.
  final KeyRelationType relation;

  /// Constructor
  const TableKey(DataType dataType, String dataClass, this.relation)
      : super(dataType, dataClass);

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {
      'type': dataType.index,
      'class': dataClass,
      'relation': relation.index
    };
  }
}

/// Primary key (raw TableField)
class PrimaryKey extends TableField {
  /// Constructor
  const PrimaryKey(DataType dataType, String dataClass)
      : super(dataType, dataClass);

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {'type': dataType.index, 'class': dataClass};
  }
}
