// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.dataserver;

/// Data table
class DataTable {
  /// Database name
  final String database;

  /// Table name
  final String table;

  /// Data is retrieved from a remote source.
  final bool remote;

  /// Data is computed rather than retrieved from a storage.
  final bool computed;

  /// Data should be cached locally by the DataServer.
  final bool localCache;

  /// Primary key
  final PrimaryKey primaryKey;

  /// Secondary table keys
  final List<TableKey> keys;

  /// Table values
  final List<TableValue> values;

  /// Parameters that are required to request data.
  final Set<String> parameters;

  /// Constructor
  const DataTable(
      {this.database,
      this.table,
      this.remote,
      this.computed,
      this.localCache,
      this.primaryKey,
      this.keys,
      this.values,
      this.parameters});

  /// Convert to JSON compatible data.
  Map<String, dynamic> toJson() {
    return {
      'database': database,
      'table': table,
      'remote': remote,
      'computed': computed,
      'localCache': localCache,
      'primaryKey': primaryKey,
      'keys': keys,
      'values': values,
      'parameters': parameters
    };
  }
}
