// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

// THIS FILE IS AUTO-GENERATED, PLEASE DO NOT MODIFY BY HAND.

part of molview_messages.v0;

/// DataServer messages
/// ===================
/// The DataServer is the central, in-memory data storage in MolView. The
/// DataServer manages the retrieval of data records from external databases and
/// web-services. It can also be used to integrate local resources with external
/// resources. Modules can submit new data tables to the DataServer. The
/// DataServer takes care of interconnecting tables and finding the best way to
/// get the data that is requested by modules. To do so the DataServer stores a
/// map of keys that link to the most recent data in the application. These keys
/// can be used to retrieve related data.

/// omnibusId for mActivateTable
const String mActivateTableId = 'molview_messages.v0.mActivateTable';

/// Activate a new resource table in the DataServer
///
/// *Arguments:*
///
/// - **table:**
///   Table information
OmnibusEvent mActivateTable(DataTable table) {
  return new OmnibusEvent(mActivateTableId, {'table': table});
}

/// omnibusId for mTableRejected
const String mTableRejectedId = 'molview_messages.v0.mTableRejected';

/// A table activation was rejected
///
/// *Arguments:*
///
/// - **reason:**
///   Rejection reason
///
/// - **message:**
///   User friendly rejection message
OmnibusEvent mTableRejected(TableRejectionReason reason, String message) {
  return new OmnibusEvent.unchecked(
      mTableRejectedId, {'reason': reason.index, 'message': message});
}

/// omnibusId for mTableRegistered
const String mTableRegisteredId = 'molview_messages.v0.mTableRegistered';

/// A new table was registered
///
/// *Arguments:*
///
/// - **table:**
///   Resource table details
OmnibusEvent mTableRegistered(DataTable table) {
  return new OmnibusEvent(mTableRegisteredId, {'table': table});
}

/// omnibusId for mRetrieveData
const String mRetrieveDataId = 'molview_messages.v0.mRetrieveData';

/// Request record from a table
///
/// *Arguments:*
///
/// - **database:**
///   Target database
///
/// - **table:**
///   Target table
///
/// - **inkeyClass:**
///   Input key data class
///
/// - **inkeyValue:**
///   Input key value
///
/// - **parameters:**
///   Retrieval parameters
///
/// - **keys:**
///   Requested keys by their index
///
/// - **values:**
///   Requested values by their index
OmnibusRequest mRetrieveData(
    String database, String table, String inkeyClass, String inkeyValue,
    {Map<String, dynamic> parameters: const {},
    List<int> keys: const [],
    List<int> values: const []}) {
  return new OmnibusRequest(mRetrieveDataId, {
    'database': database,
    'table': table,
    'inkeyClass': inkeyClass,
    'inkeyValue': inkeyValue,
    'parameters': parameters,
    'keys': keys,
    'values': values
  });
}

/// omnibusId for mDataRetrieved
const String mDataRetrievedId = 'molview_messages.v0.mDataRetrieved';

/// Return data to the DataSever
///
/// This message contain the data that is retrieved in response to an
/// mRetrieveData request.
///
/// *Arguments:*
///
/// - **records:**
///   Retrieved data records
OmnibusResponse mDataRetrieved(Set<DataRecord> records) {
  return new OmnibusResponse(mDataRetrievedId, {'records': records});
}

/// omnibusId for mSubmitData
const String mSubmitDataId = 'molview_messages.v0.mSubmitData';

/// Send data to the DataServer
///
/// *Arguments:*
///
/// - **records:**
///   Records that are sumbitted
OmnibusEvent mSubmitData(Set<DataRecord> records) {
  return new OmnibusEvent(mSubmitDataId, {'records': records});
}

/// omnibusId for mFindSnippets
const String mFindSnippetsId = 'molview_messages.v0.mFindSnippets';

/// Find data snippets
///
/// *Arguments:*
///
/// - **snippets:**
///   Requested data snippets
///
/// - **inkeyClass:**
///   Alternative starting key data class
///
/// - **inkeyValue:**
///   Alternative starting key value
OmnibusRequest mFindSnippets(Set<SnippetSelector> snippets,
    {String inkeyClass: '', String inkeyValue: ''}) {
  return new OmnibusRequest(mFindSnippetsId, {
    'snippets': snippets,
    'inkeyClass': inkeyClass,
    'inkeyValue': inkeyValue
  });
}

/// omnibusId for mSnippetsFound
const String mSnippetsFoundId = 'molview_messages.v0.mSnippetsFound';

/// Return snippets to the data consumer.
///
/// *Arguments:*
///
/// - **snippets:**
///   Resulting snippets
OmnibusResponse mSnippetsFound(Set<SnippetData> snippets) {
  return new OmnibusResponse(mSnippetsFoundId, {'snippets': snippets});
}

/// omnibusId for mTextSearch
const String mTextSearchId = 'molview_messages.v0.mTextSearch';

/// Search table using a text
///
/// *Arguments:*
///
/// - **database:**
///   Target database
///
/// - **table:**
///   Target table
///
/// - **text:**
///   Search text
///
/// - **offset:**
///   Offset for paged search
OmnibusRequest mTextSearch(
    String database, String table, String text, int offset) {
  return new OmnibusRequest.unchecked(mTextSearchId,
      {'database': database, 'table': table, 'text': text, 'offset': offset});
}

/// omnibusId for mTextSearchResults
const String mTextSearchResultsId = 'molview_messages.v0.mTextSearchResults';

/// Return results of a text search.
///
/// *Arguments:*
///
/// - **matches:**
///   N best matches for the given search text
OmnibusResponse mTextSearchResults(List<TextSearchMatch> matches) {
  return new OmnibusResponse(mTextSearchResultsId, {'matches': matches});
}

/// omnibusId for mPushActiveRecord
const String mPushActiveRecordId = 'molview_messages.v0.mPushActiveRecord';

/// Try to switch to a new active record.
///
/// *Arguments:*
///
/// - **key:**
///   Target key data class
///
/// - **value:**
///   Target key value
OmnibusEvent mPushActiveRecord(String key, dynamic value) {
  return new OmnibusEvent(mPushActiveRecordId, {'key': key, 'value': value});
}

/// omnibusId for mActiveRecordChanged
const String mActiveRecordChangedId =
    'molview_messages.v0.mActiveRecordChanged';

/// Switch to a new active record.
///
/// *Arguments:*
///
/// - **key:**
///   Target key data class
///
/// - **value:**
///   Target key value
OmnibusEvent mActiveRecordChanged(String key, dynamic value) {
  return new OmnibusEvent(mActiveRecordChangedId, {'key': key, 'value': value});
}
